@@ -29,7 +29,7 @@ def user_form(fields=None, update=False):
                 self.fields[field].required = form_config.get('required')[key]
                 self.fields[field].widget.attrs = form_config.get('classes')[key]
                 self.fields[field].widget.attrs['placeholder'] = CONFIG_JSON.get('placeholder_text', '#'). \
-                    replace('#', form_config.get('labels')[key])
+                    replace('#', str(form_config.get('labels')[key]))
 
         def clean_password(self):
             return make_password(self.cleaned_data['password'])
